{% if element.type == 'row' %}
  {% include "suit_dashboard/row.html" with row=element %}
{% elif element.type == 'widget' %}
  {% include "suit_dashboard/widget.html" with widget=element %}
{% endif %}
